siz bu kutubxona orqali virus yarata olasiz
buni ishlatish juda oson
avvalo kutubxonani o'rnatishingiz kerak
```bash
pip install uz_virus
```
keyin quyidagi kodni yozishingiz mumkin
```python
from virus import*

virus=Virus()
virus.question('are you gay?') #bu yerda ekranda qanday savol chiqishi yoziladi

virus.run()
```
bu kodni ishga tushursa ekranda "are you gay?" matni chiqadi va yes va no tugmalari bo'ladi no tugmasini bossangiz hech qachon oyna yopilmaydi yes tugmasini bosganda yopiladi